@@ -9,11 +9,16 @@ import (
 	"fmt"
 	"io/fs"
 	"os"
+	"path/filepath"
 	"text/tabwriter"
 
+	contfs "github.com/containerd/continuity/fs"
 	"github.com/docker/go-units"
-	"github.com/lima-vm/lima/pkg/qemu"
+	"github.com/lima-vm/go-qcow2reader"
+	"github.com/lima-vm/lima/pkg/nativeimgutil"
+	"github.com/lima-vm/lima/pkg/qemu/imgutil"
 	"github.com/lima-vm/lima/pkg/store"
+	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
@@ -43,6 +48,7 @@ func newDiskCommand() *cobra.Command {
 		newDiskDeleteCommand(),
 		newDiskUnlockCommand(),
 		newDiskResizeCommand(),
+		newDiskImportCommand(),
 	)
 	return diskCommand
 }
@@ -58,9 +64,9 @@ $ limactl disk create DISK --size SIZE [--format qcow2]
 		Args:  WrapArgsError(cobra.ExactArgs(1)),
 		RunE:  diskCreateAction,
 	}
-	diskCreateCommand.Flags().String("size", "", "configure the disk size")
+	diskCreateCommand.Flags().String("size", "", "Configure the disk size")
 	_ = diskCreateCommand.MarkFlagRequired("size")
-	diskCreateCommand.Flags().String("format", "qcow2", "specify the disk format")
+	diskCreateCommand.Flags().String("format", "qcow2", "Specify the disk format")
 	return diskCreateCommand
 }
 
@@ -104,7 +110,14 @@ func diskCreateAction(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	if err := qemu.CreateDataDisk(diskDir, format, int(diskSize)); err != nil {
+	// qemu may not be available, use it only if needed.
+	dataDisk := filepath.Join(diskDir, filenames.DataDisk)
+	if format == "raw" {
+		err = nativeimgutil.CreateRawDisk(dataDisk, int(diskSize))
+	} else {
+		err = imgutil.CreateDisk(dataDisk, format, int(diskSize))
+	}
+	if err != nil {
 		rerr := os.RemoveAll(diskDir)
 		if rerr != nil {
 			err = errors.Join(err, fmt.Errorf("failed to remove a directory %q: %w", diskDir, rerr))
@@ -217,7 +230,7 @@ $ limactl disk delete DISK1 DISK2 ...
 		RunE:              diskDeleteAction,
 		ValidArgsFunction: diskBashComplete,
 	}
-	diskDeleteCommand.Flags().BoolP("force", "f", false, "force delete")
+	diskDeleteCommand.Flags().BoolP("force", "f", false, "Force delete")
 	return diskDeleteCommand
 }
 
@@ -393,9 +406,18 @@ func diskResizeAction(cmd *cobra.Command, args []string) error {
 			}
 		}
 	}
-	if err := qemu.ResizeDataDisk(disk.Dir, disk.Format, int(diskSize)); err != nil {
+
+	// qemu may not be available, use it only if needed.
+	dataDisk := filepath.Join(disk.Dir, filenames.DataDisk)
+	if disk.Format == "raw" {
+		err = nativeimgutil.ResizeRawDisk(dataDisk, int(diskSize))
+	} else {
+		err = imgutil.ResizeDisk(dataDisk, disk.Format, int(diskSize))
+	}
+	if err != nil {
 		return fmt.Errorf("failed to resize disk %q: %w", diskName, err)
 	}
+
 	logrus.Infof("Resized disk %q (%q)", diskName, disk.Dir)
 	return nil
 }
@@ -403,3 +425,64 @@ func diskResizeAction(cmd *cobra.Command, args []string) error {
 func diskBashComplete(cmd *cobra.Command, _ []string, _ string) ([]string, cobra.ShellCompDirective) {
 	return bashCompleteDiskNames(cmd)
 }
+
+func newDiskImportCommand() *cobra.Command {
+	diskImportCommand := &cobra.Command{
+		Use: "import DISK FILE",
+		Example: `
+Import a disk:
+$ limactl disk import DISK DISKPATH
+`,
+		Short:             "Import an existing disk to Lima",
+		Args:              WrapArgsError(cobra.ExactArgs(2)),
+		RunE:              diskImportAction,
+		ValidArgsFunction: diskBashComplete,
+	}
+	return diskImportCommand
+}
+
+func diskImportAction(_ *cobra.Command, args []string) error {
+	diskName := args[0]
+	fName := args[1]
+
+	diskDir, err := store.DiskDir(diskName)
+	if err != nil {
+		return err
+	}
+
+	if _, err := os.Stat(diskDir); !errors.Is(err, fs.ErrNotExist) {
+		return fmt.Errorf("disk %q already exists (%q)", diskName, diskDir)
+	}
+
+	f, err := os.Open(fName)
+	if err != nil {
+		return err
+	}
+	defer f.Close()
+
+	img, err := qcow2reader.Open(f)
+	if err != nil {
+		return err
+	}
+
+	diskSize := img.Size()
+	format := img.Type()
+
+	switch format {
+	case "qcow2", "raw":
+	default:
+		return fmt.Errorf(`disk format %q not supported, use "qcow2" or "raw" instead`, format)
+	}
+
+	if err := os.MkdirAll(diskDir, 0o755); err != nil {
+		return err
+	}
+
+	if err := contfs.CopyFile(filepath.Join(diskDir, filenames.DataDisk), fName); err != nil {
+		return nil
+	}
+
+	logrus.Infof("Imported %s with size %s", diskName, units.BytesSize(float64(diskSize)))
+
+	return nil
+}
