@@ -53,7 +53,7 @@ type HostAgent struct {
 	instName          string
 	instSSHAddress    string
 	sshConfig         *ssh.SSHConfig
-	portForwarder     *portForwarder
+	portForwarder     *portForwarder // legacy SSH port forwarder (deprecated)
 	grpcPortForwarder *portfwd.Forwarder
 
 	onClose []func() error // LIFO
@@ -75,11 +75,19 @@ type HostAgent struct {
 }
 
 type options struct {
-	nerdctlArchive string // local path, not URL
+	guestAgentBinary string
+	nerdctlArchive   string // local path, not URL
 }
 
 type Opt func(*options) error
 
+func WithGuestAgentBinary(s string) Opt {
+	return func(o *options) error {
+		o.guestAgentBinary = s
+		return nil
+	}
+}
+
 func WithNerdctlArchive(s string) Opt {
 	return func(o *options) error {
 		o.nerdctlArchive = s
@@ -123,25 +131,18 @@ func New(instName string, stdout io.Writer, signalCh chan os.Signal, opts ...Opt
 		}
 	}
 
-	vSockPort := 0
-	virtioPort := ""
-	if *inst.Config.VMType == limayaml.VZ {
-		vSockPort = 2222
-	} else if *inst.Config.VMType == limayaml.WSL2 {
-		port, err := freeport.VSock()
-		if err != nil {
-			logrus.WithError(err).Error("failed to get free VSock port")
-		}
-		vSockPort = port
-	} else if *inst.Config.VMType == limayaml.QEMU {
-		// virtserialport doesn't seem to work reliably: https://github.com/lima-vm/lima/issues/2064
-		virtioPort = "" // filenames.VirtioPort
+	baseDriver := driver.BaseDriver{
+		Instance:     inst,
+		SSHLocalPort: sshLocalPort,
 	}
+	limaDriver := driverutil.CreateTargetDriverInstance(&baseDriver)
+	vSockPort := baseDriver.VSockPort
+	virtioPort := baseDriver.VirtioPort
 
 	if err := cidata.GenerateCloudConfig(inst.Dir, instName, inst.Config); err != nil {
 		return nil, err
 	}
-	if err := cidata.GenerateISO9660(inst.Dir, instName, inst.Config, udpDNSLocalPort, tcpDNSLocalPort, o.nerdctlArchive, vSockPort, virtioPort); err != nil {
+	if err := cidata.GenerateISO9660(inst.Dir, instName, inst.Config, udpDNSLocalPort, tcpDNSLocalPort, o.guestAgentBinary, o.nerdctlArchive, vSockPort, virtioPort); err != nil {
 		return nil, err
 	}
 
@@ -196,13 +197,6 @@ func New(instName string, stdout io.Writer, signalCh chan os.Signal, opts ...Opt
 	limayaml.FillPortForwardDefaults(&rule, inst.Dir, inst.Config.User, inst.Param)
 	rules = append(rules, rule)
 
-	limaDriver := driverutil.CreateTargetDriverInstance(&driver.BaseDriver{
-		Instance:     inst,
-		SSHLocalPort: sshLocalPort,
-		VSockPort:    vSockPort,
-		VirtioPort:   virtioPort,
-	})
-
 	a := &HostAgent{
 		instConfig:        inst.Config,
 		sshLocalPort:      sshLocalPort,
@@ -658,9 +652,12 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client *guestag
 		for _, f := range ev.Errors {
 			logrus.Warnf("received error from the guest: %q", f)
 		}
-		// useSSHFwd was false by default in v1.0, but reverted to true by default in v1.0.1
-		// due to stability issues
-		useSSHFwd := true
+		// History of the default value of useSSHFwd:
+		// - v0.1.0:        true  (effectively)
+		// - v1.0.0:        false
+		// - v1.0.1:        true
+		// - v1.1.0-beta.0: false
+		useSSHFwd := false
 		if envVar := os.Getenv("LIMA_SSH_PORT_FORWARDER"); envVar != "" {
 			b, err := strconv.ParseBool(os.Getenv("LIMA_SSH_PORT_FORWARDER"))
 			if err != nil {
@@ -670,6 +667,7 @@ func (a *HostAgent) processGuestAgentEvents(ctx context.Context, client *guestag
 			}
 		}
 		if useSSHFwd {
+			logrus.Warn("LIMA_SSH_PORT_FORWARDER is deprecated")
 			a.portForwarder.OnEvent(ctx, ev)
 		} else {
 			a.grpcPortForwarder.OnEvent(ctx, client, ev)
