@@ -5,12 +5,14 @@
 package nativeimgutil
 
 import (
+	"errors"
 	"fmt"
 	"io"
+	"io/fs"
 	"os"
 	"path/filepath"
 
-	"github.com/containerd/continuity/fs"
+	containerdfs "github.com/containerd/continuity/fs"
 	"github.com/docker/go-units"
 	"github.com/lima-vm/go-qcow2reader"
 	"github.com/lima-vm/go-qcow2reader/convert"
@@ -20,6 +22,37 @@ import (
 	"github.com/sirupsen/logrus"
 )
 
+// Disk image size must be aigned to sector size. Qemu block layer is rounding
+// up the size to 512 bytes. Apple virtualization framework reject disks not
+// aligned to 512 bytes.
+const sectorSize = 512
+
+// RoundUp rounds size up to sectorSize.
+func RoundUp(size int) int {
+	sectors := (size + sectorSize - 1) / sectorSize
+	return sectors * sectorSize
+}
+
+// CreateRawDisk creates an empty raw data disk.
+func CreateRawDisk(disk string, size int) error {
+	if _, err := os.Stat(disk); err == nil || !errors.Is(err, fs.ErrNotExist) {
+		return err
+	}
+	f, err := os.Create(disk)
+	if err != nil {
+		return err
+	}
+	defer f.Close()
+	roundedSize := RoundUp(size)
+	return f.Truncate(int64(roundedSize))
+}
+
+// ResizeRawDisk resizes a raw data disk.
+func ResizeRawDisk(disk string, size int) error {
+	roundedSize := RoundUp(size)
+	return os.Truncate(disk, int64(roundedSize))
+}
+
 // ConvertToRaw converts a source disk into a raw disk.
 // source and dest may be same.
 // ConvertToRaw is a NOP if source == dest, and no resizing is needed.
@@ -109,7 +142,7 @@ func ConvertToRaw(source, dest string, size *int64, allowSourceWithBackingFile b
 func convertRawToRaw(source, dest string, size *int64) error {
 	if source != dest {
 		// continuity attempts clonefile
-		if err := fs.CopyFile(dest, source); err != nil {
+		if err := containerdfs.CopyFile(dest, source); err != nil {
 			return fmt.Errorf("failed to copy %q into %q: %w", source, dest, err)
 		}
 	}
