@@ -13,6 +13,24 @@ import (
 	"gotest.tools/v3/assert"
 )
 
+func TestRoundUp(t *testing.T) {
+	tests := []struct {
+		Size    int
+		Rounded int
+	}{
+		{0, 0},
+		{1, 512},
+		{511, 512},
+		{512, 512},
+		{123456789, 123457024},
+	}
+	for _, tc := range tests {
+		if RoundUp(tc.Size) != tc.Rounded {
+			t.Errorf("expected %d, got %d", tc.Rounded, tc.Size)
+		}
+	}
+}
+
 func createImg(name, format, size string) error {
 	return exec.Command("qemu-img", "create", name, "-f", format, size).Run()
 }
@@ -43,8 +61,7 @@ func TestConvertToRaw(t *testing.T) {
 	assert.NilError(t, err)
 
 	t.Run("qcow without backing file", func(t *testing.T) {
-		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"))
-		assert.NilError(t, err)
+		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
 		err = ConvertToRaw(qcowImage.Name(), resultImage, nil, false)
 		assert.NilError(t, err)
@@ -52,8 +69,7 @@ func TestConvertToRaw(t *testing.T) {
 	})
 
 	t.Run("qcow with backing file", func(t *testing.T) {
-		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"))
-		assert.NilError(t, err)
+		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
 		err = ConvertToRaw(qcowImage.Name(), resultImage, nil, true)
 		assert.NilError(t, err)
@@ -61,8 +77,8 @@ func TestConvertToRaw(t *testing.T) {
 	})
 
 	t.Run("qcow with extra size", func(t *testing.T) {
-		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"))
-		assert.NilError(t, err)
+		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
+
 		size := int64(2_097_152) // 2mb
 		err = ConvertToRaw(qcowImage.Name(), resultImage, &size, false)
 		assert.NilError(t, err)
@@ -70,8 +86,7 @@ func TestConvertToRaw(t *testing.T) {
 	})
 
 	t.Run("raw", func(t *testing.T) {
-		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"))
-		assert.NilError(t, err)
+		resultImage := filepath.Join(tmpDir, strings.ReplaceAll(strings.ReplaceAll(t.Name(), string(os.PathSeparator), "_"), "/", "_"))
 
 		err = ConvertToRaw(rawImage.Name(), resultImage, nil, false)
 		assert.NilError(t, err)
